@@ -8,7 +8,8 @@
 % $Id
 % -----------------------------------------------------------------------------
 -module(perlre).
--export([match/2, start/0, start/1, stop/0]).
+-export([match/2]).
+-export([start/0, start/1, stop/0]).
 -import(perlport, [call/2]).
 
 % -----------------------------------------------------------------------------
@@ -16,7 +17,7 @@
 %
 match(String, Regexp) ->
 	start(),
-	call([String, Regexp], perlre).
+	call([match, String, Regexp], perlre).
 
 % -----------------------------------------------------------------------------
 % start().
